The survey dataset includes 11 variables from the 2008 edition of the American National Election Study.
anes08A data frame with 2265 rows and 11 variables:
Age of the respondent
Sex of the respondent
Non-white vs. white
No high school, some high school, high school diploma, college
Low, medium, high.
Protestant, Catholic/Orthodox, Atheist/other
Single, married, no longer married
7 response categories ranging from "Govt should let each person get ahead on own" (1) to "Govt should see to jobs and standard of living" (7)
Whether the respondent sees the environment as an important issue (important/not important)
Vote choice in the 2008 presidential election: Obama, McCain, No vote/Other
Time for the respondent to complete the survey
The dataset anes was prepared by Kropko et al. (2014). The nine
variables contain different levels of missingness.
The dataset was imputed using random value imputation and predictive
mean matching via mice::mice() (Version: 3.13.0, seed=42).
The imputed datasets are available in anes_rng (random value
imputation) and anes_pmm (predictive mean matching).
J. Kropko, B. Goodrich, A. Gelman, and J. Hill. 2014. Multiple Imputation for Continuous and Categorical Data: Comparing Joint Multivariate Normal and Conditional Approaches, Political Analysis 22(4):497<U+2013>519.