Construct parameter list for cobalt
param_cobalt(
stats = c("m", "v", "ks", "ovl"),
continuous = "std",
binary = "std",
abs = TRUE,
s.d.denom = "pooled"
)character; which statistic(s) should be reported.
whether mean differences for continuous variables should be standardized ("std") or raw ("raw").
whether mean differences for binary variables (i.e., difference in proportion) should be standardized ("std") or raw ("raw").
logical; whether displayed balance statistics should be in absolute value or not.
character; how the denominator for standardized mean differences should be calculated, if requested.
A list of parameters that can be passed to missDiag().
For more information about these parameters, see
cobalt::bal.tab().