Construct parameter list for ebalance
param_ebal(
coefs = NULL,
max.iterations = 200,
base.weight = NULL,
constraint.tolerance = 1,
norm.constant = NULL,
trim = FALSE,
max.weight = NULL,
min.weight = 0,
max.trim.iterations = 200,
max.weight.increment = 0.92,
min.weight.increment = 1.08
)starting values for model coefficients.
maximum number of iterations.
vector of base weights.
tolerance level.
An optional normalizing constant.
trim weights via ebalance.trim
Target for the ratio of the maximum to mean weight.
Target for the ratio of the minimum to mean weight.
Maximum number of trimming iterations.
Increment for iterative trimming of the ratio of the maximum to mean weight.
Increment for iterative trimming of the ratio of the minimum to mean weight.
A list of parameters that can be passed to missDiag().
For more information about these parameters, see
ebal::ebalance() and ebal::ebalance.trim().