Construct parameter list for sbw
param_sbw(
bal_alg = TRUE,
bal_tol = 0,
bal_std = "group",
bal_gri = c(0.0001, 0.001, 0.002, 0.005, 0.01, 0.02, 0.05, 0.1),
bal_sam = 1000,
sol_nam = "quadprog"
)use tuning algorithm as in Wang and Zubizarreta (2020)?
tolerance level.
tolerances adjustment.
grid of values for the tuning algorithm.
number of replicates to be used by the tuning algorithm.
solver name. Either "cplex", "gurobi", "mosek", "pogs", or "quadprog".
A list of parameters that can be passed to missDiag().
For more information about these parameters, see sbw::sbw().